@@ -122,11 +122,11 @@ pub fn build_result_line<'a, T: ResultItem + ?Sized>(
 }
 
 fn build_entry_spans<T: ResultItem + ?Sized>(
-    item: &T,
+    item: &'_ T,
     max_width: u16,
     result_fg: Color,
     match_fg: Color,
-) -> Vec<Span> {
+) -> Vec<Span<'_>> {
     let mut spans = Vec::with_capacity(16);
 
     let (mut entry_name, mut match_ranges) = make_result_item_printable(item);
@@ -208,11 +208,11 @@ fn build_entry_spans<T: ResultItem + ?Sized>(
 /// - It ensures that match highlights do not disrupt the underlying ANSI styles, except for the foreground color.
 /// - If no ANSI codes are present, it delegates to the simpler span builder for efficiency.
 fn build_entry_spans_ansi<T: ResultItem + ?Sized>(
-    item: &T,
+    item: &'_ T,
     max_width: u16,
     result_fg: Color,
     match_fg: Color,
-) -> Vec<Span> {
+) -> Vec<Span<'_>> {
     let text = item.raw();
     let match_ranges = item.match_ranges().unwrap_or(&[]);
     let parsed = text.into_text().unwrap();
